98874f1656202cd5781466a5d9b25f47da1f104d
hiram
  Mon Feb 13 16:03:53 2023 -0800
a bit closer to correct NCBI links, not perfect, but better than it was no redmine

diff --git src/hg/inc/asmEquivalent.h src/hg/inc/asmEquivalent.h
index 8463390..42c1388 100644
--- src/hg/inc/asmEquivalent.h
+++ src/hg/inc/asmEquivalent.h
@@ -78,26 +78,26 @@
 
 void asmEquivalentOutput(struct asmEquivalent *el, FILE *f, char sep, char lastSep);
 /* Print out asmEquivalent.  Separate fields with sep. Follow last field with lastSep. */
 
 #define asmEquivalentTabOut(el,f) asmEquivalentOutput(el,f,'\t','\n');
 /* Print out asmEquivalent as a line in a tab-separated file. */
 
 #define asmEquivalentCommaOut(el,f) asmEquivalentOutput(el,f,',',',');
 /* Print out asmEquivalent as a comma separated list including final comma. */
 
 void asmEquivalentJsonOutput(struct asmEquivalent *el, FILE *f);
 /* Print out asmEquivalent in JSON format. */
 
 /* -------------------------------- End autoSql Generated Code -------------------------------- */
 
-char *asmEquivalentUcscToNCBI(char *ucscName);
-/* check if there is a RefSeq/GenBank equivalent to this UCSC assembly name.
- *    If RefSeq exists, return that first, else if GenBank than return that.
+char *asmEquivalentUcscToNCBI(char *ucscName, char *authority);
+/* check if there is an "authority" equivalent to this UCSC assembly name.
+ *    where 'authority' in this case is either 'refseq' or 'genbank'
  * No checking of sequence match counts in this first implementation,
  *    therefore, could be a fuzzy match, and since it is returning only the
  *    first one, it might not be the best match.  Could add more specifics
  *    later to get better match.
  */
 
 #endif /* ASMEQUIVALENT_H */